@@ -132,6 +132,36 @@ class fillVars(object, cl_base.glob_attr):
             return lang.split("_")[0]
         return ""
 
+    def get_os_locale_xkb(self):
+        """раскладка клавиатуры для X"""
+        lang = self.Get("os_locale_lang")
+        # Языки: 
+        # Португальский - pt_BR
+        # Французский   - fr_FR
+        # Немецкий      - de_DE
+        # Русский       - ru_RU
+        # Испанский     - es_ES
+        # Украинский    - uk_UA
+        # Английский    - en_US
+        xkbDict = {'pt_BR':'br,us',
+                   'fr_FR':'fr,us',
+                   'de_DE':'de,us',
+                   'ru_RU':'us,ru(winkeys)',
+                   'es_ES':'es,us',
+                   'uk_UA':'us,ua(winkeys)',
+                   'en_US':'us'}
+        if lang:
+            if xkbDict.has_key(lang):
+                return xkbDict[lang]
+        return ""
+
+    def get_os_locale_xkbname(self):
+        """названия используемых раскладок клавиатуры для X"""
+        localeXkb = self.Get("os_locale_xkb")
+        if localeXkb:
+            return localeXkb.split("(")[0]
+        return ""
+
     def get_os_arch_machine(self):
         """архитектура процессора"""
         march = self._runos("""%s uname -m"""%self.path_env)
@@ -156,13 +186,19 @@ class fillVars(object, cl_base.glob_attr):
         mountLunes = self._runos("""%s mount"""%self.path_env)
         rootType = "hdd"
         if type(mountLunes) == types.ListType:
+            flagCD = False
             for line in mountLunes:
                 if "/dev/loop0 on / type" in line:
                     rootType = "ram"
                     break
-            if rootType == "ram" and os.path.exists("/mnt/livecd"):
-                rootType = "livecd"
-                return rootType
+                elif "/dev/loop0 on /newroot/mnt/livecd type" in line:
+                    rootType = "ram"
+                    flagCD = True
+                    break
+            if rootType == "ram":
+                if os.path.exists("/mnt/livecd") or flagCD:
+                    rootType = "livecd"
+                    return rootType
             rootDev = self.Get("os_root_dev")
             if rootType != "ram" and rootDev:
                 slpRootDev = rootDev.split("/dev/")
