@@ -51,9 +51,12 @@ class Data:
     os_locale_lang = {}
     # язык (прим: ru)
     os_locale_language = {}
-    ## поддерживаемые языки (пример: be be_BY da de en и т.д.)
-    #os_locale_linguas = {'value':'be be_BY da de en en_GB es fr it nb nn pl \
-#pt_BR ru se sv uk'}
+
+    # раскладка клавиатуры для X
+    os_locale_xkb = {}
+
+    # названия используемых раскладок клавиатуры для X
+    os_locale_xkbname = {}
 
     # архитектура компьютера (i686,x86_64)
     os_arch_machine = {}
